import * as Core from '@mux/mux-node/core';
import { APIResource } from '@mux/mux-node/resource';
import * as ErrorsAPI from '@mux/mux-node/resources/data/errors';
export declare class Errors extends APIResource {
    /**
     * Returns a list of errors.
     */
    list(query?: ErrorListParams, options?: Core.RequestOptions): Core.APIPromise<ErrorsResponse>;
    list(options?: Core.RequestOptions): Core.APIPromise<ErrorsResponse>;
}
export interface ErrorsResponse {
    data: Array<ErrorsResponse.Data>;
    timeframe: Array<number>;
    total_row_count: number | null;
}
export declare namespace ErrorsResponse {
    interface Data {
        /**
         * A unique identifier for this error.
         */
        id: number;
        /**
         * The error code
         */
        code: number | null;
        /**
         * The total number of views that experienced this error.
         */
        count: number;
        /**
         * Description of the error.
         */
        description: string | null;
        /**
         * The last time this error was seen (ISO 8601 timestamp).
         */
        last_seen: string;
        /**
         * The error message.
         */
        message: string | null;
        /**
         * Notes that are attached to this error.
         */
        notes: string | null;
        /**
         * The percentage of views that experienced this error.
         */
        percentage: number;
        /**
         * The string version of the error code
         */
        player_error_code: string | null;
    }
}
export interface ErrorListParams {
    /**
     * Limit the results to rows that match conditions from provided key:value pairs.
     * Must be provided as an array query string parameter.
     *
     * To exclude rows that match a certain condition, prepend a `!` character to the
     * dimension.
     *
     * Possible filter names are the same as returned by the List Filters endpoint.
     *
     * Example:
     *
     * - `filters[]=operating_system:windows&filters[]=!country:US`
     */
    filters?: Array<string>;
    /**
     * Limit the results to rows that match inequality conditions from provided metric
     * comparison clauses. Must be provided as an array query string parameter.
     *
     * Possible filterable metrics are the same as the set of metric ids, with the
     * exceptions of `exits_before_video_start`, `unique_viewers`,
     * `video_startup_failure_percentage`, and `views`.
     *
     * Example:
     *
     * - `metric_filters[]=aggregate_startup_time>=1000`
     */
    metric_filters?: Array<string>;
    /**
     * Timeframe window to limit results by. Must be provided as an array query string
     * parameter (e.g. timeframe[]=).
     *
     * Accepted formats are...
     *
     * - array of epoch timestamps e.g. `timeframe[]=1498867200&timeframe[]=1498953600`
     * - duration string e.g. `timeframe[]=24:hours or timeframe[]=7:days`
     */
    timeframe?: Array<string>;
}
export declare namespace Errors {
    export import ErrorsResponse = ErrorsAPI.ErrorsResponse;
    export import ErrorListParams = ErrorsAPI.ErrorListParams;
}
//# sourceMappingURL=errors.d.ts.map