import * as Core from '@mux/mux-node/core';
import { APIResource } from '@mux/mux-node/resource';
import * as TranscriptionVocabulariesAPI from '@mux/mux-node/resources/video/transcription-vocabularies';
import { BasePage, type BasePageParams } from '@mux/mux-node/pagination';
export declare class TranscriptionVocabularies extends APIResource {
    /**
     * Create a new Transcription Vocabulary.
     */
    create(body: TranscriptionVocabularyCreateParams, options?: Core.RequestOptions): Core.APIPromise<TranscriptionVocabulary>;
    /**
     * Retrieves the details of a Transcription Vocabulary that has previously been
     * created. Supply the unique Transcription Vocabulary ID and Mux will return the
     * corresponding Transcription Vocabulary information. The same information is
     * returned when creating a Transcription Vocabulary.
     */
    retrieve(transcriptionVocabularyId: string, options?: Core.RequestOptions): Core.APIPromise<TranscriptionVocabulary>;
    /**
     * Updates the details of a previously-created Transcription Vocabulary. Updates to
     * Transcription Vocabularies are allowed while associated live streams are active.
     * However, updates will not be applied to those streams while they are active.
     */
    update(transcriptionVocabularyId: string, body: TranscriptionVocabularyUpdateParams, options?: Core.RequestOptions): Core.APIPromise<TranscriptionVocabulary>;
    /**
     * List all Transcription Vocabularies.
     */
    list(query?: TranscriptionVocabularyListParams, options?: Core.RequestOptions): Core.PagePromise<TranscriptionVocabulariesBasePage, TranscriptionVocabulary>;
    list(options?: Core.RequestOptions): Core.PagePromise<TranscriptionVocabulariesBasePage, TranscriptionVocabulary>;
    /**
     * Deletes a Transcription Vocabulary. The Transcription Vocabulary's ID will be
     * disassociated from any live streams using it. Transcription Vocabularies can be
     * deleted while associated live streams are active. However, the words and phrases
     * in the deleted Transcription Vocabulary will remain attached to those streams
     * while they are active.
     */
    delete(transcriptionVocabularyId: string, options?: Core.RequestOptions): Core.APIPromise<void>;
}
export declare class TranscriptionVocabulariesBasePage extends BasePage<TranscriptionVocabulary> {
}
export interface TranscriptionVocabulary {
    /**
     * Unique identifier for the Transcription Vocabulary
     */
    id: string;
    /**
     * Time the Transcription Vocabulary was created, defined as a Unix timestamp
     * (seconds since epoch).
     */
    created_at: string;
    /**
     * Time the Transcription Vocabulary was updated, defined as a Unix timestamp
     * (seconds since epoch).
     */
    updated_at: string;
    /**
     * The user-supplied name of the Transcription Vocabulary.
     */
    name?: string;
    /**
     * Arbitrary user-supplied metadata set for the Transcription Vocabulary. Max 255
     * characters.
     */
    passthrough?: string;
    /**
     * Phrases, individual words, or proper names to include in the Transcription
     * Vocabulary. When the Transcription Vocabulary is attached to a live stream's
     * `generated_subtitles` configuration, the probability of successful speech
     * recognition for these words or phrases is boosted.
     */
    phrases?: Array<string>;
}
export interface TranscriptionVocabularyResponse {
    data: TranscriptionVocabulary;
}
export interface TranscriptionVocabularyCreateParams {
    /**
     * Phrases, individual words, or proper names to include in the Transcription
     * Vocabulary. When the Transcription Vocabulary is attached to a live stream's
     * `generated_subtitles`, the probability of successful speech recognition for
     * these words or phrases is boosted.
     */
    phrases: Array<string>;
    /**
     * The user-supplied name of the Transcription Vocabulary.
     */
    name?: string;
    /**
     * Arbitrary user-supplied metadata set for the Transcription Vocabulary. Max 255
     * characters.
     */
    passthrough?: string;
}
export interface TranscriptionVocabularyUpdateParams {
    /**
     * Phrases, individual words, or proper names to include in the Transcription
     * Vocabulary. When the Transcription Vocabulary is attached to a live stream's
     * `generated_subtitles`, the probability of successful speech recognition for
     * these words or phrases is boosted.
     */
    phrases: Array<string>;
    /**
     * The user-supplied name of the Transcription Vocabulary.
     */
    name?: string;
    /**
     * Arbitrary user-supplied metadata set for the Transcription Vocabulary. Max 255
     * characters.
     */
    passthrough?: string;
}
export interface TranscriptionVocabularyListParams extends BasePageParams {
}
export declare namespace TranscriptionVocabularies {
    export import TranscriptionVocabulary = TranscriptionVocabulariesAPI.TranscriptionVocabulary;
    export import TranscriptionVocabularyResponse = TranscriptionVocabulariesAPI.TranscriptionVocabularyResponse;
    export import TranscriptionVocabulariesBasePage = TranscriptionVocabulariesAPI.TranscriptionVocabulariesBasePage;
    export import TranscriptionVocabularyCreateParams = TranscriptionVocabulariesAPI.TranscriptionVocabularyCreateParams;
    export import TranscriptionVocabularyUpdateParams = TranscriptionVocabulariesAPI.TranscriptionVocabularyUpdateParams;
    export import TranscriptionVocabularyListParams = TranscriptionVocabulariesAPI.TranscriptionVocabularyListParams;
}
//# sourceMappingURL=transcription-vocabularies.d.ts.map